# Copyright (C) 2009  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

package PrepareGallery;

our @ISA = qw(Exporter);
our @EXPORT = qw( preparegallery );
our @EXPORT_OK = qw();

use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
use Exporter;

use File::Copy;
use File::Basename;
use File::Spec;
use File::Path;

use constant TRUE => (1==1);
use constant FALSE => (1==0);

#------------------------------------------------------
#
# Global vars
#
#------------------------------------------------------

# Version number
my $VERSION = "2.1" ;

my $lock = File::Spec->catfile($ENV{'HOME'},".prepare-gallery.lock");

sub lock() {
    system("lockfile-create '$lock'");
}

sub unlock() {
    system("lockfile-remove '$lock'");
}

sub makeQuote($) {
	my $txt = shift || '';
	my $hasQuote = ($txt =~ /\'/s);
	my $hasQQuote = ($txt =~ /\"/s);
	my $t = "$txt";
	if ($hasQuote && $hasQQuote) {
		$t =~ s/\"/\\\"/sg;
		$t = "\"$t\"";
	}
	elsif ($hasQuote) {
		$t = "\"$t\"";
	}
	elsif ($hasQQuote) {
		$t = "\'$t\'";
	}
	else {
		$t = "'$t'";
	}
	return "$t";
}

#------------------------------------------------------
#
# PREPAREGALLERY
#
#------------------------------------------------------
sub preparegallery(@) {
	my $callback = shift || undef;
	my $targetDir = shift;
	my $quality = shift;
	my $width = shift || 600;
	my $height = shift || 450;
	my $name = shift || 'gallery';
	my $firstnumber = shift;
	my $title = shift || '';
	my $description = shift || '';
	my $isTextOnly = shift || FALSE;

	my @errors = ();

	print "Waiting for previous execution termination...";
	lock();
	print "done\n";

	# Ensure no special char in name
	$name =~ s/[^a-zA-Z0-9_\.]/_/gs;

	my $geometry = $width.'x'.$height;

	if ($quality<0) {
		$quality = 0;
	}
	elsif ($quality>100) {
		$quality = 100;
	}

	my $outputDir;

	{
		$outputDir = File::Spec->catfile("$targetDir","gallery");
		my $count = 0;
		while (-e "$outputDir") {
			$count++;
			$outputDir = File::Spec->catfile("$targetDir","gallery$count");
		}
	}

	if (! -d "$outputDir") {
		mkpath("$outputDir") or die("$outputDir: $!\n");
	}

	my $index = $firstnumber - 1;

	foreach my $imgFile (@_) {

		$index ++;

		my $basename = basename("$imgFile");
		my $ext = '';
		my $sname = '';
		if ($basename =~ /^(.*?)\.([^.]+)$/) {
			$sname = "$1";
			$ext = "$2";
		}

		$sname = "$name$index";

		my $outFile = File::Spec->catfile($outputDir,"$sname.$ext");
		my $outBasename = basename("$outFile");

		if (!$isTextOnly) {
			print "Resizing $basename -> $outBasename...";
			copy("$imgFile","$outFile") or die("$imgFile->$outFile: $!\n");
			my $cmd = "mogrify -quality $quality -resize $geometry ".makeQuote("$outFile");
			print "\n$cmd\n";
			system("$cmd");
			if ($?) {
				push @errors, "$basename";
				print "ERROR\n";
			}
			else {
				print "done\n";
			}
		}

		$outFile = File::Spec->catfile($outputDir,"$sname.txt");
		my $txtBasename = basename("$outFile");

		print "Creating descriptor $outBasename...";
		local *FILE;
		open(*FILE, "> $outFile") or die("$outFile: $!\n");
		print FILE "Lien\n";
		print FILE "$title\n";
		print FILE "$description\n";
		close(*FILE);
		print "done\n";

		if (defined($callback)) {
			$callback->();
		}

	}

	unlock();

	return ($outputDir,\@errors);
}


1;
__END__
