#!/usr/bin/perl -w
#
# prepare-gallery - resize each image given on the command line and generate txt file.
# Copyright (C) 2009  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
# 

use strict;
use File::Basename;
use File::Spec;
use File::Path;
use File::Copy;
use Getopt::Long;

my $PERLSCRIPTDIR ;
my $PERLSCRIPTNAME ;
my $LAUNCHINGNAME ;
{
	BEGIN{
	  # Where is this script?
	  $PERLSCRIPTDIR = "$0";
	  $LAUNCHINGNAME = basename("$0");
	  my $scriptdir = dirname( $PERLSCRIPTDIR );
	  while ( -e $PERLSCRIPTDIR && -l $PERLSCRIPTDIR ) {
	    $PERLSCRIPTDIR = readlink($PERLSCRIPTDIR);
	    if ( substr( $PERLSCRIPTDIR, 0, 1 ) eq '.' ) {
	      $PERLSCRIPTDIR = File::Spec->catfile( $scriptdir, "$PERLSCRIPTDIR" ) ;
	    }
	    $scriptdir = dirname( $PERLSCRIPTDIR );
	  }
	  $PERLSCRIPTNAME = basename( $PERLSCRIPTDIR ) ;
	  $PERLSCRIPTDIR = dirname( $PERLSCRIPTDIR ) ;
	  $PERLSCRIPTDIR = File::Spec->rel2abs( "$PERLSCRIPTDIR" );
	  # Push the path where the script is to retreive the arakhne.org packages
	  push(@INC,"$PERLSCRIPTDIR");
	  push(@INC,File::Spec->catfile("$PERLSCRIPTDIR","pm"));
	}
}

use PrepareGallery;

my $quality = 100;
my $defaultName = "gallery";
my $defaultTitle = "<Titre>";
my $defaultDescription = "<Description>";
my @size = ( 600, 450 );
my $txtonly = 0;
my $firstnumber = 1;
my $destination = undef;

sub usage() {
    print "usage:\n";
    print "\tprepare-gallery [options] fichier1 [fichier2 ... ]\n";
    print "\n\texemple: prepare-gallery --hauteur 480 foo1.jpg foo2.jpg foo3.jpg\n\n";
    print "options:\n";
    print "\t--txtseul\n";
    print "\t--destination <nom de dossier>\n";
    print "\t--qualite <0-100>\n";
    print "\t--taille <largeur> <hauteur>\n";
    print "\t--hauteur <hauteur>\n";
    print "\t--largeur <largeur>\n";
    print "\t--nom <nom des images et des fichiers txt>\n";
    print "\t--premiernumero <premier numero des fichiers>\n";
    print "\t--titre <titre dans les fichiers txt>\n";
    print "\t--description <description dans les fichiers txt>\n";
    exit(1);
}

if (!GetOptions( 'qualite=i' => \$quality,
		 'taille=i{2}' => sub { if (@size==2) { @size = (); } push @size, int($_[1]); },
		 'largeur=i' => sub { @size = (int($_[1]),-1); },
		 'hauteur=i' => sub { @size = (-1,int($_[1])); },
		 'nom=s' => \$defaultName,
		 'titre=s' => \$defaultTitle,
		 'description=s' => \$defaultDescription,
		 'txtseul' => \$txtonly,
		 'premiernumero=i' => \$firstnumber,
		 'destination=s' => \$destination,
               )) {
	usage();
}

if (!@ARGV) {
	usage();
}

if (!$destination) {
	$destination = File::Spec->curdir();
}

preparegallery(
	undef, # no callback
	$destination,
	$quality,
	$size[0],
	$size[1],
	$defaultName,
	$firstnumber,
	$defaultTitle,
	$defaultDescription,
	$txtonly,
	@ARGV);

exit(0);

__END__

